# profilometer
import numpy as np
import pandas as pd
from .misc import *
__all__ = ['parse_oscilloscope_electrical']

def read_files(input_path, output_path, plot_path, hist_path, interactive=False):
    with open(input_path, "r") as f:
        lines = f.readlines()

    df = pd_read_csv( 
        filename=input_path, encoding="utf-8", sep=",", header_count=16, 
        names_old=["erase1", "Voltage (V)", "erase2"], names_new=["erase1", "Voltage (V)", "erase2"], unit_conversion_coefficients=[1, 1, 1], 
        use_index=True, name_index="time (ns)", index_coefficient=4E-013*1e9
    )
    df.to_csv(output_path, index=False)
    p = Plot(df, interactive=interactive)
    p.plot(plot_path)
    p.hist(hist_path)

def parse_oscilloscope_electrical(**kwargs):
    read_files(kwargs["input_path"], kwargs["output_path"], kwargs["plot_path"], kwargs["hist_path"])



import os, glob
from .parse_all import *

__copyright__    = 'Copyright (C) 2022 BoronSpoon'
__version__      = '1.3.23b'
__license__      = 'MIT License'
__author__       = 'boronspoon'
__author_email__ = 'rayanticlimactic@gmail.com'
__url__          = 'http://github.com/BoronSpoon/vern'

__all__ = [
    #os.path.split(os.path.splitext(file)[0])[1] for file in glob.glob(os.path.join(os.path.dirname(__file__), '*.py')) if '__' not in file
    'Vern'
]